#!/bin/bash

# Script to deploy the entire VoxPop platform

# Exit on any error
set -e

# Set variables
ENV=${1:-development}
PROJECT_ROOT=$(dirname "$(dirname "$(realpath "$0")")")
SCRIPTS_DIR="$PROJECT_ROOT/scripts"

echo "Deploying VoxPop platform in $ENV environment..."

# Make scripts executable
chmod +x "$SCRIPTS_DIR/deploy-backend.sh"
chmod +x "$SCRIPTS_DIR/deploy-frontend.sh"

# Deploy backend services
echo "Deploying backend services..."
"$SCRIPTS_DIR/deploy-backend.sh" "$ENV"

# Deploy analysis service
echo "Deploying analysis service..."
cd "$PROJECT_ROOT/analysis"
docker-compose up -d

# Deploy frontend
echo "Deploying frontend..."
"$SCRIPTS_DIR/deploy-frontend.sh" "$ENV"

echo "VoxPop platform deployment completed successfully!" 